@@ -1,11 +1,10 @@
-import os
 import numpy as np
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
-from synthesizer.models.global_style_token import GlobalStyleToken
-from synthesizer.gst_hyperparameters import GSTHyperparameters as gst_hp
-from synthesizer.hparams import hparams
+from .global_style_token import GlobalStyleToken
+from ..gst_hyperparameters import GSTHyperparameters as gst_hp
+from ..hparams import hparams
 
 
 class HighwayNetwork(nn.Module):
@@ -13,13 +12,13 @@ class HighwayNetwork(nn.Module):
         super().__init__()
         self.W1 = nn.Linear(size, size)
         self.W2 = nn.Linear(size, size)
-        self.W1.bias.data.fill_(0.)
+        self.W1.bias.data.fill_(0.0)
 
     def forward(self, x):
         x1 = self.W1(x)
         x2 = self.W2(x)
         g = torch.sigmoid(x2)
-        y = g * F.relu(x1) + (1. - g) * x
+        y = g * F.relu(x1) + (1.0 - g) * x
         return y
 
 
@@ -29,11 +28,16 @@ class Encoder(nn.Module):
         prenet_dims = (encoder_dims, encoder_dims)
         cbhg_channels = encoder_dims
         self.embedding = nn.Embedding(num_chars, embed_dims)
-        self.pre_net = PreNet(embed_dims, fc1_dims=prenet_dims[0], fc2_dims=prenet_dims[1],
-                              dropout=dropout)
-        self.cbhg = CBHG(K=K, in_channels=cbhg_channels, channels=cbhg_channels,
-                         proj_channels=[cbhg_channels, cbhg_channels],
-                         num_highways=num_highways)
+        self.pre_net = PreNet(
+            embed_dims, fc1_dims=prenet_dims[0], fc2_dims=prenet_dims[1], dropout=dropout
+        )
+        self.cbhg = CBHG(
+            K=K,
+            in_channels=cbhg_channels,
+            channels=cbhg_channels,
+            proj_channels=[cbhg_channels, cbhg_channels],
+            num_highways=num_highways,
+        )
 
     def forward(self, x, speaker_embedding=None):
         x = self.embedding(x)
@@ -77,7 +81,9 @@ class Encoder(nn.Module):
 class BatchNormConv(nn.Module):
     def __init__(self, in_channels, out_channels, kernel, relu=True):
         super().__init__()
-        self.conv = nn.Conv1d(in_channels, out_channels, kernel, stride=1, padding=kernel // 2, bias=False)
+        self.conv = nn.Conv1d(
+            in_channels, out_channels, kernel, stride=1, padding=kernel // 2, bias=False
+        )
         self.bnorm = nn.BatchNorm1d(out_channels)
         self.relu = relu
 
@@ -136,7 +142,7 @@ class CBHG(nn.Module):
 
         # Convolution Bank
         for conv in self.conv1d_bank:
-            c = conv(x) # Convolution
+            c = conv(x)  # Convolution
             conv_bank.append(c[:, :, :seq_len])
 
         # Stack along the channel axis
@@ -156,7 +162,8 @@ class CBHG(nn.Module):
         x = x.transpose(1, 2)
         if self.highway_mismatch is True:
             x = self.pre_highway(x)
-        for h in self.highways: x = h(x)
+        for h in self.highways:
+            x = h(x)
 
         # And then the RNN
         x, _ = self.rnn(x)
@@ -167,6 +174,7 @@ class CBHG(nn.Module):
         to improve efficiency and avoid PyTorch yelling at us."""
         [m.flatten_parameters() for m in self._to_flatten]
 
+
 class PreNet(nn.Module):
     def __init__(self, in_dims, fc1_dims=256, fc2_dims=128, dropout=0.5):
         super().__init__()
@@ -206,9 +214,11 @@ class Attention(nn.Module):
 class LSA(nn.Module):
     def __init__(self, attn_dim, kernel_size=31, filters=32):
         super().__init__()
-        self.conv = nn.Conv1d(1, filters, padding=(kernel_size - 1) // 2, kernel_size=kernel_size, bias=True)
+        self.conv = nn.Conv1d(
+            1, filters, padding=(kernel_size - 1) // 2, kernel_size=kernel_size, bias=True
+        )
         self.L = nn.Linear(filters, attn_dim, bias=False)
-        self.W = nn.Linear(attn_dim, attn_dim, bias=True) # Include the attention bias in this term
+        self.W = nn.Linear(attn_dim, attn_dim, bias=True)  # Include the attention bias in this term
         self.v = nn.Linear(attn_dim, 1, bias=False)
         self.cumulative = None
         self.attention = None
@@ -221,7 +231,8 @@ class LSA(nn.Module):
 
     def forward(self, encoder_seq_proj, query, t, chars):
 
-        if t == 0: self.init_attention(encoder_seq_proj)
+        if t == 0:
+            self.init_attention(encoder_seq_proj)
 
         processed_query = self.W(query).unsqueeze(1)
 
@@ -247,30 +258,44 @@ class Decoder(nn.Module):
     # Class variable because its value doesn't change between classes
     # yet ought to be scoped by class because its a property of a Decoder
     max_r = 20
-    def __init__(self, n_mels, encoder_dims, decoder_dims, lstm_dims,
-                 dropout, speaker_embedding_size):
+
+    def __init__(
+        self, n_mels, encoder_dims, decoder_dims, lstm_dims, dropout, speaker_embedding_size
+    ):
         super().__init__()
         self.register_buffer("r", torch.tensor(1, dtype=torch.int))
         self.n_mels = n_mels
         prenet_dims = (decoder_dims * 2, decoder_dims * 2)
-        self.prenet = PreNet(n_mels, fc1_dims=prenet_dims[0], fc2_dims=prenet_dims[1],
-                             dropout=dropout)
+        self.prenet = PreNet(
+            n_mels, fc1_dims=prenet_dims[0], fc2_dims=prenet_dims[1], dropout=dropout
+        )
         self.attn_net = LSA(decoder_dims)
         if hparams.use_gst:
             speaker_embedding_size += gst_hp.E
-        self.attn_rnn = nn.GRUCell(encoder_dims + prenet_dims[1] + speaker_embedding_size, decoder_dims)
-        self.rnn_input = nn.Linear(encoder_dims  + decoder_dims + speaker_embedding_size, lstm_dims)
+        self.attn_rnn = nn.GRUCell(
+            encoder_dims + prenet_dims[1] + speaker_embedding_size, decoder_dims
+        )
+        self.rnn_input = nn.Linear(encoder_dims + decoder_dims + speaker_embedding_size, lstm_dims)
         self.res_rnn1 = nn.LSTMCell(lstm_dims, lstm_dims)
         self.res_rnn2 = nn.LSTMCell(lstm_dims, lstm_dims)
         self.mel_proj = nn.Linear(lstm_dims, n_mels * self.max_r, bias=False)
         self.stop_proj = nn.Linear(encoder_dims + speaker_embedding_size + lstm_dims, 1)
 
     def zoneout(self, prev, current, device, p=0.1):
-        mask = torch.zeros(prev.size(),device=device).bernoulli_(p)
+        mask = torch.zeros(prev.size(), device=device).bernoulli_(p)
         return prev * mask + current * (1 - mask)
 
-    def forward(self, encoder_seq, encoder_seq_proj, prenet_in,
-                hidden_states, cell_states, context_vec, t, chars):
+    def forward(
+        self,
+        encoder_seq,
+        encoder_seq_proj,
+        prenet_in,
+        hidden_states,
+        cell_states,
+        context_vec,
+        t,
+        chars,
+    ):
 
         # Need this for reshaping mels
         batch_size = encoder_seq.size(0)
@@ -300,7 +325,7 @@ class Decoder(nn.Module):
         # Compute first Residual RNN
         rnn1_hidden_next, rnn1_cell = self.res_rnn1(x, (rnn1_hidden, rnn1_cell))
         if self.training:
-            rnn1_hidden = self.zoneout(rnn1_hidden, rnn1_hidden_next,device=device)
+            rnn1_hidden = self.zoneout(rnn1_hidden, rnn1_hidden_next, device=device)
         else:
             rnn1_hidden = rnn1_hidden_next
         x = x + rnn1_hidden
@@ -315,7 +340,7 @@ class Decoder(nn.Module):
 
         # Project Mels
         mels = self.mel_proj(x)
-        mels = mels.view(batch_size, self.n_mels, self.max_r)[:, :, :self.r]
+        mels = mels.view(batch_size, self.n_mels, self.max_r)[:, :, : self.r]
         hidden_states = (attn_hidden, rnn1_hidden, rnn2_hidden)
         cell_states = (rnn1_cell, rnn2_cell)
 
@@ -328,27 +353,42 @@ class Decoder(nn.Module):
 
 
 class Tacotron(nn.Module):
-    def __init__(self, embed_dims, num_chars, encoder_dims, decoder_dims, n_mels, 
-                 fft_bins, postnet_dims, encoder_K, lstm_dims, postnet_K, num_highways,
-                 dropout, stop_threshold, speaker_embedding_size):
+    def __init__(
+        self,
+        embed_dims,
+        num_chars,
+        encoder_dims,
+        decoder_dims,
+        n_mels,
+        fft_bins,
+        postnet_dims,
+        encoder_K,
+        lstm_dims,
+        postnet_K,
+        num_highways,
+        dropout,
+        stop_threshold,
+        speaker_embedding_size,
+    ):
         super().__init__()
         self.n_mels = n_mels
         self.lstm_dims = lstm_dims
         self.encoder_dims = encoder_dims
         self.decoder_dims = decoder_dims
         self.speaker_embedding_size = speaker_embedding_size
-        self.encoder = Encoder(embed_dims, num_chars, encoder_dims,
-                               encoder_K, num_highways, dropout)
+        self.encoder = Encoder(
+            embed_dims, num_chars, encoder_dims, encoder_K, num_highways, dropout
+        )
         project_dims = encoder_dims + speaker_embedding_size
-        if hparams.use_gst: 
+        if hparams.use_gst:
             project_dims += gst_hp.E
         self.encoder_proj = nn.Linear(project_dims, decoder_dims, bias=False)
-        if hparams.use_gst: 
+        if hparams.use_gst:
             self.gst = GlobalStyleToken(speaker_embedding_size)
-        self.decoder = Decoder(n_mels, encoder_dims, decoder_dims, lstm_dims,
-                               dropout, speaker_embedding_size)
-        self.postnet = CBHG(postnet_K, n_mels, postnet_dims,
-                            [postnet_dims, fft_bins], num_highways)
+        self.decoder = Decoder(
+            n_mels, encoder_dims, decoder_dims, lstm_dims, dropout, speaker_embedding_size
+        )
+        self.postnet = CBHG(postnet_K, n_mels, postnet_dims, [postnet_dims, fft_bins], num_highways)
         self.post_proj = nn.Linear(postnet_dims, fft_bins, bias=False)
 
         self.init_model()
@@ -364,11 +404,10 @@ class Tacotron(nn.Module):
     @r.setter
     def r(self, value):
         self.decoder.r = self.decoder.r.new_tensor(value, requires_grad=False)
-    
+
     @staticmethod
     def _concat_speaker_embedding(outputs, speaker_embeddings):
-        speaker_embeddings_ = speaker_embeddings.expand(
-            outputs.size(0), outputs.size(1), -1)
+        speaker_embeddings_ = speaker_embeddings.expand(outputs.size(0), outputs.size(1), -1)
         outputs = torch.cat([outputs, speaker_embeddings_], dim=-1)
         return outputs
 
@@ -376,7 +415,7 @@ class Tacotron(nn.Module):
         device = texts.device  # use same device as parameters
 
         self.step += 1
-        batch_size, _, steps  = mels.size()
+        batch_size, _, steps = mels.size()
 
         # Initialise all hidden states and pack into tuple
         attn_hidden = torch.zeros(batch_size, self.decoder_dims, device=device)
@@ -401,9 +440,11 @@ class Tacotron(nn.Module):
         # SV2TTS: Run the encoder with the speaker embedding
         # The projection avoids unnecessary matmuls in the decoder loop
         encoder_seq = self.encoder(texts, speaker_embedding)
-        # put after encoder 
+        # put after encoder
         if hparams.use_gst and self.gst is not None:
-            style_embed = self.gst(speaker_embedding, speaker_embedding) # for training, speaker embedding can represent both style inputs and referenced
+            style_embed = self.gst(
+                speaker_embedding, speaker_embedding
+            )  # for training, speaker embedding can represent both style inputs and referenced
             # style_embed = style_embed.expand_as(encoder_seq)
             # encoder_seq = torch.cat((encoder_seq, style_embed), 2)
             encoder_seq = self._concat_speaker_embedding(encoder_seq, style_embed)
@@ -415,9 +456,16 @@ class Tacotron(nn.Module):
         # Run the decoder loop
         for t in range(0, steps, self.r):
             prenet_in = mels[:, :, t - 1] if t > 0 else go_frame
-            mel_frames, scores, hidden_states, cell_states, context_vec, stop_tokens = \
-                self.decoder(encoder_seq, encoder_seq_proj, prenet_in,
-                             hidden_states, cell_states, context_vec, t, texts)
+            mel_frames, scores, hidden_states, cell_states, context_vec, stop_tokens = self.decoder(
+                encoder_seq,
+                encoder_seq_proj,
+                prenet_in,
+                hidden_states,
+                cell_states,
+                context_vec,
+                t,
+                texts,
+            )
             mel_outputs.append(mel_frames)
             attn_scores.append(scores)
             stop_outputs.extend([stop_tokens] * self.r)
@@ -441,7 +489,7 @@ class Tacotron(nn.Module):
         self.eval()
         device = x.device  # use same device as parameters
 
-        batch_size, _  = x.size()
+        batch_size, _ = x.size()
 
         # Need to initialise all hidden states and pack into tuple for tidyness
         attn_hidden = torch.zeros(batch_size, self.decoder_dims, device=device)
@@ -467,17 +515,19 @@ class Tacotron(nn.Module):
         # The projection avoids unnecessary matmuls in the decoder loop
         encoder_seq = self.encoder(x, speaker_embedding)
 
-        # put after encoder 
+        # put after encoder
         if hparams.use_gst and self.gst is not None:
             if style_idx >= 0 and style_idx < 10:
                 query = torch.zeros(1, 1, self.gst.stl.attention.num_units)
-                if device.type == 'cuda':
+                if device.type == "cuda":
                     query = query.cuda()
                 gst_embed = torch.tanh(self.gst.stl.embed)
                 key = gst_embed[style_idx].unsqueeze(0).expand(1, -1, -1)
                 style_embed = self.gst.stl.attention(query, key)
             else:
-                speaker_embedding_style = torch.zeros(speaker_embedding.size()[0], 1, self.speaker_embedding_size).to(device)
+                speaker_embedding_style = torch.zeros(
+                    speaker_embedding.size()[0], 1, self.speaker_embedding_size
+                ).to(device)
                 style_embed = self.gst(speaker_embedding_style, speaker_embedding)
             encoder_seq = self._concat_speaker_embedding(encoder_seq, style_embed)
             # style_embed = style_embed.expand_as(encoder_seq)
@@ -490,14 +540,22 @@ class Tacotron(nn.Module):
         # Run the decoder loop
         for t in range(0, steps, self.r):
             prenet_in = mel_outputs[-1][:, :, -1] if t > 0 else go_frame
-            mel_frames, scores, hidden_states, cell_states, context_vec, stop_tokens = \
-            self.decoder(encoder_seq, encoder_seq_proj, prenet_in,
-                         hidden_states, cell_states, context_vec, t, x)
+            mel_frames, scores, hidden_states, cell_states, context_vec, stop_tokens = self.decoder(
+                encoder_seq,
+                encoder_seq_proj,
+                prenet_in,
+                hidden_states,
+                cell_states,
+                context_vec,
+                t,
+                x,
+            )
             mel_outputs.append(mel_frames)
             attn_scores.append(scores)
             stop_outputs.extend([stop_tokens] * self.r)
             # Stop the loop when all stop tokens in batch exceed threshold
-            if (stop_tokens * 10 > min_stop_token).all() and t > 10: break
+            if (stop_tokens * 10 > min_stop_token).all() and t > 10:
+                break
 
         # Concat the mel outputs into sequence
         mel_outputs = torch.cat(mel_outputs, dim=2)
@@ -506,7 +564,6 @@ class Tacotron(nn.Module):
         postnet_out = self.postnet(mel_outputs)
         linear = self.post_proj(postnet_out)
 
-
         linear = linear.transpose(1, 2)
 
         # For easy visualisation
@@ -519,14 +576,18 @@ class Tacotron(nn.Module):
 
     def init_model(self):
         for p in self.parameters():
-            if p.dim() > 1: nn.init.xavier_uniform_(p)
+            if p.dim() > 1:
+                nn.init.xavier_uniform_(p)
 
     def finetune_partial(self, whitelist_layers):
         self.zero_grad()
         for name, child in self.named_children():
             if name in whitelist_layers:
                 print("Trainable Layer: %s" % name)
-                print("Trainable Parameters: %.3f" % sum([np.prod(p.size()) for p in child.parameters()]))
+                print(
+                    "Trainable Parameters: %.3f"
+                    % sum([np.prod(p.size()) for p in child.parameters()])
+                )
                 for param in child.parameters():
                     param.requires_grad = False
 
@@ -551,15 +612,20 @@ class Tacotron(nn.Module):
 
     def save(self, path, optimizer=None):
         if optimizer is not None:
-            torch.save({
-                "model_state": self.state_dict(),
-                "optimizer_state": optimizer.state_dict(),
-            }, str(path))
+            torch.save(
+                {
+                    "model_state": self.state_dict(),
+                    "optimizer_state": optimizer.state_dict(),
+                },
+                str(path),
+            )
         else:
-            torch.save({
-                "model_state": self.state_dict(),
-            }, str(path))
-
+            torch.save(
+                {
+                    "model_state": self.state_dict(),
+                },
+                str(path),
+            )
 
     def num_params(self, print_out=True):
         parameters = filter(lambda p: p.requires_grad, self.parameters())
